import 'package:varargs/varargs.dart';
import 'package:test/test.dart';

/// The first arguments is a `List<dynamic>` of the positioned arguments,
/// and the second arguments is a `Map<Symbol, dynamic>` of the named arguments.
/// If you want to access a named argument, you should use the `Symbol`
/// instead of the variable name which is usually a `String`.
/// See the below examples in the `example/` directory.
int echo(List positioned, Map named) {
  if (named.containsKey('key')) {
    // This condition does not pass the test.
    // You can not use a `String` to a key.
    print(named['key']);
  }
  // The first method to access the named arguments.
  if (named.containsKey(#key2)) {
    print(named[#key2]);
  }
  // The second method to access the named arguments.
  if (named.containsKey(Symbol('key3'))) {
    print(named[#key3]);
  }
  return positioned.length + named.length;
}

/// You can also create async functions.
Future<int> asyncEcho(List positioned, Map named) async {
  print('This is an async varargs function');
  return positioned.length + named.length;
}

void main() {
  group('Basic tests', () {
    test('Sync VarArgs with positioned arguments only', () {
      expect(echo.varArgs(1, 2, 3, 4, 5), 5);
    });
    test('Sync VarArgs with named arguments only', () {
      expect(echo.varArgs(named: 'hi', key: 'key', key2: 'test'), 3);
    });
    test('Sync VarArgs with all', () {
      expect(echo.varArgs(1, 2, 3, 4, 5, named: 'hi', key: 'key', key2: 'test'),
          8);
    });
    test('Async VarArgs with positioned arguments only', () async {
      expect(await asyncEcho.varArgs(1, 2, 3, 4, 5), 5);
    });
    test('Async VarArgs with named arguments only', () async {
      expect(await asyncEcho.varArgs(named: 'named', key: 'key'), 2);
    });
    test('Async VarArgs with all', () async {
      expect(await asyncEcho.varArgs(1, 2, 3, named: 'named', key: 'key'), 5);
    });
  });
}
